#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-splice-plugin-2.3.0.0-6CRgPIgpIXLj3TOrKfTD
key:                  hls-splice-plugin-2.3.0.0-6CRgPIgpIXLj3TOrKfTD
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  575f5181d3da3e1f0ae4d00c655df026
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.3.0.0-6CRgPIgpIXLj3TOrKfTD
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1 containers-0.6.7
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp extra-1.7.16-aWEq6cZZ289lIc6yxljo5
    foldl-1.4.18-334bPsHCjhEA5hWHSKnVfK ghc-9.6.6
    ghc-exactprint-1.7.1.0-ChNWjXf4QA9FZ8mrPVcpuc
    ghcide-2.3.0.0-JSGU2hqwpKP2T9zGvf4q95
    hls-plugin-api-2.3.0.0-4CgmjbnqzKN1c7iCNmzWCS
    hls-refactor-plugin-2.3.0.0-7nfmrTmFclc1Y9my0YTLIc
    lens-5.3.5-JKPJsUIkx0YEZ4W3JntdKw
    lsp-2.2.0.0-AMvH8uI6CvNFs6ZEiC2ocP mtl-2.3.1
    retrie-1.2.3-IgGQtR5FjAAp2uuXwy0GM syb-0.7.4-CWkOfF6Y0mt62kPybHOEB1
    text-2.0.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

